@@ -714,4 +714,8 @@ function unique(arr) {
         }
     }
     return a;
+}
+function auto_grow(element) {
+    element.style.height = "5px";
+    element.style.height = (element.scrollHeight)+"px";
 }
\ No newline at end of file
